#!/bin/bash

# Helper functions to set up the right site-info.def,
# and to run yaim with the proper arguments

scriptdir=`dirname $0`
export scriptdir
testname=`basename $0 | sed 's,test_\(.*\).sh,\1,'`

if [ -z "$TESTNAME" ]; then
    TESTNAME=$testname
fi

yaim_prepare() {
    # make a pristine copy of site-info.def to use
    cp $scriptdir/site-info-orig.def /tmp/site-info.$TESTNAME
    rm -f /opt/glite/yaim/log/yaimlog
    rm -f /tmp/$TESTNAME.out
}


# run yaim

yaim_run() {
    if [ $# -ge 1 ] && [ "$1" = '-v' ]; then
	action='-v'
    else
	action='-c'
    fi
    /opt/glite/yaim/bin/yaim $action -s /tmp/site-info.$TESTNAME -n GLEXEC_wn >> /tmp/$TESTNAME.out 2>&1
}


yaim_finish() {
    mv /opt/glite/yaim/log/yaimlog /tmp/$TESTNAME.yaimlog
}

seterrmsg() {
    echo "$@" >&2
}


# modify the indicated variable in the test's site-info.def
# needs 2 args: varname, value
yaim_setvar() {
    if [ $# -ne 2 ]; then
	echo "call to yaim_setvar needs 2 args: <varname> <value>" >&2
	echo "got: $@" >&2
	return 1
    fi

    # no quotes, you need to add them yourself if you want them
    sed -i "s,^$1=.*,," /tmp/site-info.$TESTNAME
    echo "$1=$2" >> /tmp/site-info.$TESTNAME
}

# one arg
yaim_getvar() {
    if [ $# -ne 1 ]; then
	echo "call to yaim_getvar needs 1 arg: <varname>" >&2
	echo "got: $@" >&2
	return 1
    fi
    # stupid but effective
    sed -n "s,^$1=,,p" /tmp/site-info.$TESTNAME

}

# error codes from yaim/bin/yaim

YEX_OK=0           # successful termination
YEX_NOFUNC=1       # One of the functions returned with error without specifying it's nature !
YEX_USAGE=64       # command line usage error
YEX_DATAERR=65     # data format error
YEX_NOINPUT=66     # cannot open input
YEX_NOUSER=67      # addressee unknown
YEX_NOHOST=68      # host name unknown
YEX_UNAVAILABLE=69 # service unavailable
YEX_SOFTWARE=70    # internal software error
YEX_OSERR=71       # system error (e.g., can't fork)
YEX_OSFILE=72      # critical OS file missing
YEX_CANTCREAT=73   # can't create (user) output file
YEX_IOERR=74       # input/output error
YEX_TEMPFAIL=75    # temp failure; user is invited to retry
YEX_PROTOCOL=76    # remote error in protocol
YEX_NOPERM=77      # permission denied
YEX_CONFIG=78      # configuration error

# These are YAIM own exit codes

YEX_NOTARGET=90    # The function list definition file for the configuration target hasn't been found
YEX_MISSINGVAR=91  # Missing variables in the configuration files
YEX_NOSUCHFILE=92  # No such file or directory
YEX_CONFFILE=93    # Configuration file error
YEX_NOUSER=94      # User doesn't exist
YEX_USERERR=95     # Error when creating a user
YEX_GROUPERR=96    # Error when creating a group
YEX_CONFTARGET=97  # Wrong configuration target
